@@ -6,6 +6,7 @@ class Timecop
 
       def initialize(mock_type, *args)
         raise "Unknown mock_type #{mock_type}" unless [:freeze, :travel, :scale].include?(mock_type)
+        @travel_offset  = @scaling_factor = nil
         @scaling_factor = args.shift if mock_type == :scale
         @mock_type      = mock_type
         @time           = parse_time(*args)
@@ -75,12 +76,8 @@ class Timecop
 
       def datetime(datetime_klass = DateTime)
         if Float.method_defined?(:to_r)
-          if !sec.zero?
-            fractions_of_a_second = time.to_f % 1
-            datetime_klass.new(year, month, day, hour, min, (fractions_of_a_second + sec), utc_offset_to_rational(utc_offset))
-          else 
-            datetime_klass.new(year, month, day, hour, min, sec, utc_offset_to_rational(utc_offset))
-          end
+          fractions_of_a_second = time.to_f % 1
+          datetime_klass.new(year, month, day, hour, min, (fractions_of_a_second + sec), utc_offset_to_rational(utc_offset))
         else
           datetime_klass.new(year, month, day, hour, min, sec, utc_offset_to_rational(utc_offset))
         end
@@ -137,4 +134,4 @@ class Timecop
         Time.respond_to?(:zone) && Time.zone ? Time.zone : Time
       end
     end
-  end
+end
