@@ -4,7 +4,7 @@ require File.join(File.dirname(__FILE__), '..', 'lib', 'timecop')
 
 require 'active_support/all'
 
-class TestTimeStackItem < Test::Unit::TestCase
+class TestTimeStackItem < Minitest::Unit::TestCase
   def teardown
     Timecop.return
     Time.zone = nil
@@ -204,16 +204,12 @@ class TestTimeStackItem < Test::Unit::TestCase
   end
 
   def test_parse_date
-    assert_nothing_raised do
-      Timecop.freeze(Date.new(2012, 6, 9))
-    end
+    Timecop.freeze(Date.new(2012, 6, 9))
   end
 
   def test_time_zone_returns_nil
     Time.zone = nil
-    assert_nothing_raised do
-      Timecop.freeze
-    end
+    Timecop.freeze
   end
 
   def test_nsecs_are_set
@@ -273,7 +269,7 @@ class TestTimeStackItem < Test::Unit::TestCase
 
   def test_datetime_timezones
     dt = DateTime.new(2011,1,3,15,25,0,"-6")
-    Timecop.travel(dt) do
+    Timecop.freeze(dt) do
       now = DateTime.now
       assert_equal dt, now, "#{dt.to_f}, #{now.to_f}"
     end
