@@ -293,7 +293,7 @@ class TestTimecop < Minitest::Unit::TestCase
       end
     end
   end
-  
+
   def test_freeze_without_arguments_instance_works_as_expected
     t = Time.local(2008, 10, 10, 10, 10, 10)
     Timecop.freeze(t) do
@@ -519,6 +519,23 @@ class TestTimecop < Minitest::Unit::TestCase
     end
   end
 
+  def test_frozen_after_freeze
+    Timecop.freeze
+    assert Timecop.frozen?
+  end
+
+  def test_frozen_inside_freeze
+    Timecop.freeze do
+      assert Timecop.frozen?
+    end
+  end
+
+  def test_not_frozen_after_return
+    Timecop.freeze
+    Timecop.return
+    assert !Timecop.frozen?
+  end
+
   private
 
   def with_safe_mode(enabled=true)
